%Output: Investigation of False Positive Rate (FPR) and False Negatve Rate
%(FNR) for graphs of varying dimensions as sample size increases
%Related figures: Fig S11 (supplements)

% it takes a long time to run (more than 4hrs).
addpath(genpath('functions'))
rng(10) % for reproducibility
k=0; % 0 marginal concentration
n_list=[200 400 840 1600 3200 6400];
all_prop_edges_on=0.25;
d_all=[8,16,24];
num_edges_all=d_all.*(d_all-1)/2;

optO.burnin=200;optO.thin=50;

num_sim=30;
num_nlist=length(n_list);
num_d=length(d_all);
all_pvals_tg=cell(1,num_d);
all_pvals_plv=cell(1,num_d);
%%
for ni=1:num_nlist
    optO.nsamp=n_list(ni);
    for di=1:num_d
        d=d_all(di);
        num_edges=num_edges_all(di);
        [di/num_d, ni/num_nlist] % this is a progress indicator
        
        num_edges_on=all_prop_edges_on*num_edges;
        
        if mod(num_edges_on,1) == 0 % checking that we have whole edges
            sim_true_edges=zeros(num_edges,1);
            sim_true_edges(1:num_edges_on)=1;
            pval_allr_tg=nan(num_edges,num_sim);
            pval_allr_plv=nan(num_edges,num_sim);
            parfor r=1:num_sim
                phi_true=[  k*cos(zeros(d,1));...
                    k*sin(zeros(d,1));...
                    sim_true_edges;...
                    zeros(num_edges,1);...
                    zeros(num_edges,1);...
                    zeros(num_edges,1)];
                Xsim_samples=sampleGibbs_tutorial(d, phi_true, optO);
                
                % fitting full torus graphs, though the underlying
                % model is only phase differences with zero marginals
                [~,edges]=torus_graphs(Xsim_samples);
                % fitting torus graphs with underlying model
                %                    [~,edges]=torus_graphs(Xsim_samples,[],[],[false true false]);
                pval_allr_tg(:,r)=edges.p_vals;
                
                [~, pval_allr_plv(:,r)]=phase_locking_value(Xsim_samples)
                
            end
            all_pvals_tg{di}(:,:,ni)=pval_allr_tg;
            all_pvals_plv{di}(:,:,ni)=pval_allr_plv;
        end
    end
end
%% visual inspection of results
for di=1:num_d
    alpha_level=0.05/num_edges_all(di);
    for ni=1:num_nlist
        figure;
        subplot(211);imagesc(all_pvals_plv{di}(:,:,ni));colorbar;title('PLV pvalues');caxis([0,alpha_level])
        subplot(212);imagesc(all_pvals_tg{di}(:,:,ni));caxis([0,alpha_level]);colorbar;title('TG pvalues')
        title(sprintf(sprintf('d=%i, sample size=%i',d_all(di),n_list(ni))))
    end
end
%%
FPR_pval_tg=nan(num_d,num_nlist);
FNR_pval_tg=nan(num_d,num_nlist);
FPR_pval_plv=nan(num_d,num_nlist);
FNR_pval_plv=nan(num_d,num_nlist);

% Choose whether to correct the p-values for multiple [edge] comparisons
% (Bonferroni correction).
bf_correct=true;
% bf_correct=false;

for ni=1:num_nlist
    for di=1:num_d
        num_edges=num_edges_all(di);
        if bf_correct
            alpha_level=0.05/num_edges_all(di);
        else
            alpha_level=0.05;
        end
        num_edges_on=all_prop_edges_on*num_edges;
        
        sim_true_edges=false(num_edges,1);
        sim_true_edges(1:num_edges_on)=true;
        
        [FPR_pval_tg(di,ni),FNR_pval_tg(di,ni)]=false_rates(sim_true_edges,all_pvals_tg{di}(:,:,ni),alpha_level);
        [FPR_pval_plv(di,ni),FNR_pval_plv(di,ni)]=false_rates(sim_true_edges,all_pvals_plv{di}(:,:,ni),alpha_level);
    end
end

figure('color','w');
subplot(221);hold on
plot(n_list,FPR_pval_plv,'o-','linewidth',2)
ylabel('FPR'); xlabel('Sample size')
legend({'plv-8d','plv-16d','plv-24d'});ylim([0 1])
set(gca,'xscale','log','fontsize',16,'xtick',n_list)

if bf_correct
    title(sprintf('pvalue threshold is 0.05/numEdges'))
else
    title(sprintf('pvalue threshold is 0.05'))
end

subplot(223);hold on
plot(n_list,FNR_pval_plv,'.-','linewidth',2)
ylabel('FNR=1-TPR'); xlabel('Sample size')
legend({'plv-8d','plv-16d','plv-24d'});ylim([0 1])
set(gca,'xscale','log','fontsize',16,'xtick',n_list)

subplot(222);hold on
plot(n_list,FPR_pval_tg,'o-','linewidth',2)
ylabel('FPR'); xlabel('Sample size')
legend({'tg-8d','tg-16d','tg-24d'});ylim([0 1])
set(gca,'xscale','log','fontsize',16,'xtick',n_list)

subplot(224);hold on
plot(n_list,FNR_pval_tg,'.-','linewidth',2)
ylabel('FNR=1-TPR'); xlabel('Sample size')
legend({'tg-8d','tg-16d','tg-24d'});ylim([0 1])
set(gca,'xscale','log','fontsize',16,'xtick',n_list)


%%

